"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const resize_observer_polyfill_1 = __importDefault(require("resize-observer-polyfill"));
const react_1 = require("react");
function useComponentSize(ref) {
    const [size, setSize] = react_1.useState({
        width: 0,
        height: 0,
    });
    const timeoutRef = react_1.useRef(null);
    react_1.useEffect(() => {
        if (!ref.current)
            return;
        setSize({
            width: ref.current.clientWidth,
            height: ref.current.clientHeight
        });
        const handleResize = (entries) => {
            if (timeoutRef.current !== null) {
                window.clearTimeout(timeoutRef.current);
            }
            timeoutRef.current = window.setTimeout(() => {
                entries.forEach(({ target }) => {
                    if (size.width !== target.clientWidth ||
                        size.height !== target.clientHeight) {
                        setSize({
                            width: target.clientWidth,
                            height: target.clientHeight
                        });
                    }
                });
            }, 20);
        };
        const sizeObserver = new resize_observer_polyfill_1.default(handleResize);
        sizeObserver.observe(ref.current);
        return () => {
            if (timeoutRef.current !== null) {
                window.clearTimeout(timeoutRef.current);
            }
            sizeObserver.disconnect();
        };
    }, [ref]);
    return size;
}
exports.default = useComponentSize;
//# sourceMappingURL=useComponentSize.js.map